@@ -16,7 +16,7 @@ from Espalier import TreeOps
 from Espalier.Viterbi import viterbi
 from Espalier.Reconciler import ReconciledTree
 from Espalier import Dendro2TSConverter
-import Utils
+from Espalier import Utils
 import dendropy
 import numpy as np
 from scipy.stats import poisson
